---------------------------------------------------------------------
--== Import ===--
---------------------------------------------------------------------

import "Turbine.Gameplay"
import "Turbine.UI"
import "Turbine.UI.Lotro"
import "Souru.RaidEffects.Type"
import "Souru.RaidEffects.Class"
import "Souru.RaidEffects.Players"
import "Souru.RaidEffects.UI"

---------------------------------------------------------------------
--==  ===--
---------------------------------------------------------------------

 local status  = 0
control_miniraid = Turbine.UI.Control()

function control_miniraid:Update()
	if status == 1 then
        Turbine.PluginManager.UnloadScriptState( "RaidEffectsReloader" )
    elseif status > 1 then
        self:SetWantsUpdates( false )
        
        control_miniraid = nil
	end

    status = status + 1
end

control_miniraid:SetWantsUpdates( true )

Windows = {}
FoundEffects = {}

options = nil
EffectsLibrary = nil

moving = false

player = Turbine.Gameplay.LocalPlayer.GetInstance()

collectEffects = false
onlySearchDebuffs = false

players = {}

---------------------------------------------------------------------
--== misc ===--
---------------------------------------------------------------------

function changeCollect(bool)
	collectEffects = bool
end

function changeSearchDebuffs(bool)
	onlySearchDebuffs = bool
end

function saveLibrary()
	Turbine.PluginData.Save(Turbine.DataScope.Account, "RE_EffectsLibrary", EffectsLibrary)
end

function saveSettings()
	Turbine.PluginData.Save(Turbine.DataScope.Character, "RE_CharacterSettings", CharacterSettings)
end

function SecondsToClock(seconds)
  local seconds = tonumber(seconds)

  if seconds <= 0 then
    return "00:00";
  else
  --  hours = string.format("%02.f", math.floor(seconds/3600));
    mins = string.format("%02.f", math.floor(seconds/60));
    secs = string.format("%02.f", math.floor(seconds - mins *60));
    return mins..":"..secs
  end
end


findfont = function(number)
	if number == 1 then
		return Turbine.UI.Lotro.Font.Arial12;
	elseif number == 2 then
		return Turbine.UI.Lotro.Font.TrajanPro13;
	elseif number == 3 then
		return Turbine.UI.Lotro.Font.TrajanPro14;
	elseif number == 4 then
		return Turbine.UI.Lotro.Font.TrajanPro15;
	elseif number == 5 then
		return Turbine.UI.Lotro.Font.TrajanPro16;
	elseif number == 6 then
		return Turbine.UI.Lotro.Font.TrajanPro18;
	elseif number == 7 then
		return Turbine.UI.Lotro.Font.TrajanPro19;
	elseif number == 8 then
		return Turbine.UI.Lotro.Font.TrajanPro20;
	elseif number == 9 then
		return Turbine.UI.Lotro.Font.TrajanPro21;
	elseif number == 10 then
		return Turbine.UI.Lotro.Font.TrajanPro23;
	elseif number == 11 then
		return Turbine.UI.Lotro.Font.TrajanPro24;
	elseif number == 12 then
		return Turbine.UI.Lotro.Font.TrajanPro25;
	elseif number == 13 then
		return Turbine.UI.Lotro.Font.TrajanPro26;
	elseif number == 14 then
		return Turbine.UI.Lotro.Font.TrajanPro28;
	elseif number == 15 then
		return Turbine.UI.Lotro.Font.TrajanProBold16;
	elseif number == 16 then
		return Turbine.UI.Lotro.Font.TrajanProBold22;
	elseif number == 17 then
		return Turbine.UI.Lotro.Font.TrajanProBold24;
	elseif number == 18 then
		return Turbine.UI.Lotro.Font.TrajanProBold25;
	elseif number == 19 then
		return Turbine.UI.Lotro.Font.TrajanProBold30;
	elseif number == 20 then
		return Turbine.UI.Lotro.Font.TrajanProBold36;
	elseif number == 21 then
		return Turbine.UI.Lotro.Font.Verdana10;
	elseif number == 22 then
		return Turbine.UI.Lotro.Font.Verdana12;
	elseif number == 23 then
		return Turbine.UI.Lotro.Font.Verdana14;
	elseif number == 24 then
		return Turbine.UI.Lotro.Font.Verdana16;
	elseif number == 25 then
		return Turbine.UI.Lotro.Font.Verdana18;
	elseif number == 26 then
		return Turbine.UI.Lotro.Font.Verdana20;
	elseif number == 27 then
		return Turbine.UI.Lotro.Font.Verdana22;
	elseif number == 28 then
		return Turbine.UI.Lotro.Font.Verdana23;
	end
end

---------------------------------------------------------------------
--==  window functions ===--
---------------------------------------------------------------------

function MoveWindows(bool)

	moving = bool

	for i,window in ipairs(Windows) do
		window:Move(bool)
	end

end

function ClearWindows()
	
	for i,window in ipairs(Windows) do
		Windows[i]:Remove()
		Windows[i] = nil
	end
	
end

function CreateWindows()

	if table.getn(Windows) > 0 then
		ClearWindows()
	end

	for i,data in ipairs(CharacterSettings["window"]) do
		Windows[i] = UI.Window(data)
	end

end

function RemoveWindow(id)

	local index = nil

	for i, book in ipairs(EffectsLibrary) do
		if book["id"] == id then
			index = i
			break
		end
	end

	if index ~= nil then
		
		for i=index, table.getn(EffectsLibrary)-1, 1 do
		
			EffectsLibrary[i] = EffectsLibrary[i+1]
		
		end
		
		EffectsLibrary[table.getn(EffectsLibrary)] = nil
		
		for j, settings in ipairs(CharacterSettings["window"]) do
			
				if settings["bookID"] == id then
					RemoveSettings(j)
				end
			
		end
		
		saveLibrary()
		saveSettings()
		CreateWindows()
		
	end

end

function AddNewWindow()

	local index = table.getn(EffectsLibrary)+1

	EffectsLibrary[index] = {}
	EffectsLibrary[index]["id"] = EffectsLibrary["nextid"]
	EffectsLibrary[index]["name"] = "New Window"
	
	EffectsLibrary["nextid"] = EffectsLibrary["nextid"]+1
	
	AddNewSettings(EffectsLibrary[index]["id"], true)
	CreateWindows()
	saveLibrary()
	saveSettings()
	
	return index

end

function RemoveSettings(index)

	for i=index, table.getn(CharacterSettings["window"])-1, 1 do
	
		CharacterSettings["window"][i] = CharacterSettings["window"][i+1]
	
	end
	
	CharacterSettings["window"][table.getn(CharacterSettings["window"])] = nil

end


function AddNewSettings(bookID, loadoption)

	local index = table.getn(CharacterSettings["window"])+1
	
	CharacterSettings["window"][index] = {}
	CharacterSettings["window"][index]["load"] = loadoption
	CharacterSettings["window"][index]["bookID"] = bookID
	CharacterSettings["window"][index]["left"] = 300
	CharacterSettings["window"][index]["top"] = 100
	CharacterSettings["window"][index]["height"] = 20
	CharacterSettings["window"][index]["width"] = 150
	CharacterSettings["window"][index]["spacing"] = 4
	CharacterSettings["window"][index]["font"] = 25
	CharacterSettings["window"][index]["threshold"] = 4

end

function AddToLibrary(page)

	for i,x in ipairs(EffectsLibrary["savedeffects"]) do
		if x["name"] == page["name"] then
			if x["icon"] == page["icon"] then
				return
			end
		end
 	end
	
	local index = table.getn(EffectsLibrary["savedeffects"])+1
	
	EffectsLibrary["savedeffects"][index] = {}
	EffectsLibrary["savedeffects"][index]["name"] = page["name"]
	EffectsLibrary["savedeffects"][index]["icon"] = page["icon"]
	EffectsLibrary["savedeffects"][index]["isdebuff"] = page["isdebuff"]
	
	saveLibrary()

end

function AddPage(book, page)

	local index = table.getn(book)+1

	book[index] = {}
	book[index]["name"] = page["name"]
	book[index]["icon"] = page["icon"]
	book[index]["isdebuff"] = page["isdebuff"]
	
	AddToLibrary(page)
	
	saveLibrary()
	
	CreateWindows()


end

function RemovePage(book, page)

	local index = nil

	for i, p in ipairs(book) do
		if p["name"] == page["name"] then
			if p["icon"] == page["icon"] then
				index = i
				break
			end
		end
	end
	
	if index ~= nil then
		checkForCollection(page["name"], page["icon"], page["isdebuff"])
	
		for i=index, table.getn(book)-1, 1 do
		
			book[i] = book[i+1]
		
		end
		
		book[table.getn(book)] = nil
		saveLibrary()
		saveSettings()
		CreateWindows()
		
	end

end

---------------------------------------------------------------------
--== effect functions ===--
---------------------------------------------------------------------

function checkWindows(effect, sender, bookID)

	for k,window in ipairs(CharacterSettings["window"]) do
		
		if window["bookID"] == bookID then
		
			Windows[k]:EffectAdded(effect, sender)
		
		end
		
	end

end

function checkEffect(effect, sender)

	local name = string.lower(effect:GetName())
	local icon = effect:GetIcon()
	
	for i,book in ipairs(EffectsLibrary) do
	
		for j,page in ipairs(book) do
		
			if page["name"] == name then

				if page["icon"] ~= nil then
				
					if page["icon"] == icon then
					
						checkWindows(effect, sender, book["id"])
					
					end
				
				else
				
					checkWindows(effect, sender, book["id"])
				
				end
			
			end
		
		end
	
	end
	
	if collectEffects then
		local debuff = effect:IsDebuff()				
		if onlySearchDebuffs == true and debuff == false then 
			return
		end					
		checkForCollection( string.lower( effect:GetName() ),effect:GetIcon(), debuff)
	end

end

function checkForCollection(name, icon, isdebuff)

	for i,item in ipairs(FoundEffects) do	
		if item["name"] == name then		
			if item["icon"] == icon then			
				return			
			end			
		end	
	end
	
	local index = table.getn(FoundEffects)+1
	
	FoundEffects[index] = {}
	FoundEffects[index]["name"] = name
	FoundEffects[index]["icon"] = icon
	FoundEffects[index]["isdebuff"] = isdebuff
	
		
	if options ~= nil then
		options:UpdateSessionList()
	end
	
end

---------------------------------------------------------------------
--== party functions ===--
---------------------------------------------------------------------

function lookingForMember()

	lff()
--	Turbine.Shell.WriteLine("RaidEffects: Found "..table.getn(players).." Player(s) to track.")

end

player.PartyChanged = function(sender, args)
	lff()
end

Turbine.Chat.Received = function( sender, args )
    if args.ChatType == Turbine.ChatType.Fellowship then 
        local message = string.lower( args.Message )

        --"You have joined the chat room for your raid, raid chat is now available."
        local raid = string.find( message,( "Chat_Raid_Convert") )

        --Convert to raid
        if raid then
            lff()
        end
    end

    if args.ChatType == Turbine.ChatType.Standard then
        local message = string.lower( args.Message )

        --" has joined your Fellowship."
        local fellowship_join, _ = string.find( message, "Chat_Fellowship_Join"  )
        --" has joined your Raid."
        local raid_join, _ = string.find( message, ( "Chat_Raid_Join" ) )

        --------------------------------------------------------------------------------------------------------

        --"You have joined a Fellowship."
        local fellowship_join_self, _ = string.find( message, ( "Chat_Fellowship_Join_Self" ) )
        --"You have joined a Raid."
        local raid_join_self, _ = string.find( message, ( "Chat_Raid_Join_Self" ) )

        --------------------------------------------------------------------------------------------------------

        --" has left your Fellowship."
        local fellowship_leave, _ = string.find( message, ( "Chat_Fellowship_Leave" ) )
        --" has left your Raid."
        local raid_leave, _ = string.find( message, ( "Chat_Raid_Leave" ) )

        --------------------------------------------------------------------------------------------------------

        --"You leave your Fellowship."
        local fellowship_leave_self, _ = string.find( message, ( "Chat_Fellowship_Leave_Self" ) )
        --"You leave your Raid."
        local raid_leave_self, _ = string.find( message, ( "Chat_Raid_Leave_Self" ) )

        --------------------------------------------------------------------------------------------------------

        --"You dismiss "
        local _, self_dismiss_start = string.find( message, ( "Chat_Self_Dismiss_Start" ) )
        --" from the fellowship."
        local fellowship_dismiss_end, _ = string.find( message, ( "Chat_Fellowship_Dismiss_End" ) )
        --" from the Raid."
        local raid_dismiss_end, _ = string.find( message, ( "Chat_Raid_Dismiss_End" ) )

        --------------------------------------------------------------------------------------------------------

        --" has been dismissed from your Fellowship."
        local fellowship_dismiss, _ = string.find( message, ( "Chat_Fellowship_Dismiss" ) )
        --" has been dismissed from your Raid."
        local raid_dismiss, _ = string.find( message, ( "Chat_Raid_Dismiss" ) )

        --------------------------------------------------------------------------------------------------------

        --You have been dismissed from your Fellowship."
        local fellowship_dismiss_self, _ = string.find( message, ( "Chat_Fellowship_Dismiss_Self" ) )
        --"You have been dismissed from your Raid."
        local raid_dismiss_self, _ = string.find( message, ( "Chat_Raid_Dismiss_Self" ) )

        --------------------------------------------------------------------------------------------------------

        --"Your Fellowship has been disbanded."
        local fellowship_disband, _ = string.find( message, ( "Chat_Fellowship_Disband" ) )
        --"Your Raid has been disbanded."
        local raid_disband, _ = string.find( message, ( "Chat_Raid_Disband" ) )

        --------------------------------------------------------------------------------------------------------

        if fellowship_join or raid_join then
            lff()
        end

        if fellowship_join_self or raid_join_self then
            lff()
        end

        if fellowship_leave or raid_leave then
           lff()
        end

        if fellowship_leave_self or raid_leave_self then
           lff()
        end

        if self_dismiss_start and ( fellowship_dismiss_end or raid_dismiss_end ) then
           lff()
        end

        if fellowship_dismiss or raid_dismiss then
          lff()
        end

        if fellowship_dismiss_self or raid_dismiss_self then
          lff()
        end

        if fellowship_disband or raid_disband then
           lff()
        end
    end
end 

---------------------------------------------------------------------
--== load in ===--
---------------------------------------------------------------------

function checkForSettings(id)

	for i,setting in ipairs(CharacterSettings["window"]) do
		if setting["bookID"] == id then
			return true
		end
  	end
	
	return false

end

function checkForBook(id)

	for i,book in ipairs(EffectsLibrary) do
		if book["id"] == id then
			return true
		end
	end
	
	return false

end

function loadin()

	if Turbine.PluginData.Load(Turbine.DataScope.Account, "RE_EffectsLibrary") ~= nil then
		
		EffectsLibrary = Turbine.PluginData.Load(Turbine.DataScope.Account, "RE_EffectsLibrary")

	else

		EffectsLibrary = {}		
		EffectsLibrary["nextid"] = 1			
		EffectsLibrary["savedeffects"] = {}

				
		saveLibrary()
		
	end
	
	if Turbine.PluginData.Load(Turbine.DataScope.Character, "RE_CharacterSettings") ~= nil then
	
		CharacterSettings = Turbine.PluginData.Load(Turbine.DataScope.Character, "RE_CharacterSettings")

	else

		CharacterSettings = {}

		CharacterSettings["options"] = {}
		CharacterSettings["options"]["show"] = false
		CharacterSettings["options"]["left"] = 300
		CharacterSettings["options"]["top"] = 100
		CharacterSettings["options"]["width"] = 850
		CharacterSettings["options"]["height"] = 600

		CharacterSettings["window"] = {}


		saveSettings()
		
	end
	
	for i,book in ipairs(EffectsLibrary) do
	
		if checkForSettings(book["id"]) == false then 
			AddNewSettings(book["id"], false)
			Turbine.Shell.WriteLine("RaidEffects: Settings for "..book["name"].." added.")
			saveSettings()
		end
	
	end
	
	for j,setting in ipairs(CharacterSettings["window"]) do
	
		if checkForBook(setting["bookID"]) == false then 
			RemoveSettings(j)
			Turbine.Shell.WriteLine("RaidEffects: Settings for BookID["..setting["bookID"].."] removed.")
			saveSettings()
		end
	
	end
	
	CreateWindows()
	
end
loadin()

---------------------------------------------------------------------
--== options/library ===--
---------------------------------------------------------------------

function CloseOptions()

	options = nil
	CharacterSettings["options"]["show"] = false
	saveSettings()
end


function CreateOptions()

	if options == nil then
		options = UI.Options(CharacterSettings["options"]["left"],CharacterSettings["options"]["top"],CharacterSettings["options"]["width"],CharacterSettings["options"]["height"])
		 CharacterSettings["options"]["show"] = true
		 saveSettings()
	end

end


lff()

if CharacterSettings["options"]["show"] then
	options = UI.Options(CharacterSettings["options"]["left"],CharacterSettings["options"]["top"],CharacterSettings["options"]["width"],CharacterSettings["options"]["height"])
end

---------------------------------------------------------------------
--== Chat-Comands  ===--
---------------------------------------------------------------------

command = Turbine.ShellCommand()

function command:Execute( _, str )
    if str == nil or string.len( str ) == 0 then
        return
    end

    local list  = { }
    local index = 1

    for word in str:gmatch( "%w+" ) do
        list[ index ] = word
        index = index + 1
    end

    local cmd = string.lower( list[ 1 ] )

    if cmd == "options" then
       
	   CreateOptions()
	   
    elseif cmd == "reload" then

	Turbine.PluginManager.LoadPlugin( "RaidEffectsReloader" )
	   
	  
    elseif table.getn(list) == 2 then

		if list[1] == "unload" then
		
			for i,window in ipairs(SaveFile) do
				if string.lower(window["name"]) == string.lower(list[2]) then
					window["visible"] = false
					Turbine.Shell.WriteLine("Window: ''"..list[2].."'' turned off.")
					 CreateWindows()
					 return
				end
			end
			
			Turbine.Shell.WriteLine( "Invalid Window Name: " .. string.lower(list[1]) )
		
		elseif list[1] == "load" then
		
			for i,window in ipairs(SaveFile) do
				if string.lower(window["name"]) == string.lower(list[2]) then
					window["visible"] = true
					Turbine.Shell.WriteLine("Window: ''"..list[2].."'' turned on.")
					 CreateWindows()
					 return
				end
			end
			
			Turbine.Shell.WriteLine( "Invalid Window Name: " .. list[1] )

		else
		
			Turbine.Shell.WriteLine( "Invalid command: " .. cmd )
		
		end
		
	else
        Turbine.Shell.WriteLine( "Invalid command: " .. cmd )
    end
end

Turbine.Shell.AddCommand( "raideffects", command )
Turbine.Shell.AddCommand( "rae", command )

--Turbine.Shell.WriteLine("RaidEffects: usage: /raideffects [options][reload][load <windowname>][unload <windowname>]")