
Bar = class( Turbine.UI.Control )

function Bar:Constructor(effect, data, name, sender)
	Turbine.UI.Control.Constructor( self )
	
	self.data = data
	self.name = name
	self.sender = sender
	self.effect = effect
	
	self.inThreshold = false
	
	if self.threshold == nil then
		self.threshold = 4		
	else
		self.threshold	= tonumber(self.data["threshold"])
	end
	
	self.duration = effect:GetDuration()	
	
	if self.duration > 999 then
		self.duration = 5
	end
	self.endPoint = effect:GetStartTime()+self.duration	
	self.followEndPoint = 0
	
	self.barsize = (self.data["width"]-self.data["height"])-2
	
	self:SetSize(self.data["width"], self.data["height"]+self.data["spacing"])
	self:SetMouseVisible(false)

	
	self.frame = Turbine.UI.Control()
	self.frame:SetParent(self)
	self.frame:SetBackColor(Turbine.UI.Color.Black)
	self.frame:SetSize(self.data["width"], self.data["height"])
	self.frame:SetMouseVisible(false)
	
	self.background = Turbine.UI.Window()
	self.background:SetParent(self)
	self.background:SetSize(self.data["width"]-2, self.data["height"]-2)
	self.background:SetPosition(1,1)
	self.background:SetBackColor(Turbine.UI.Color(0.3,0.3,0.3))
	self.background:SetVisible(true)
	self.background:SetMouseVisible(false)
	
	self.icon = Turbine.UI.Control()
	self.icon:SetParent(self.background)
	self.icon:SetSize(32,32)
	self.icon:SetStretchMode(1)
	self.icon:SetBackground(effect:GetIcon())
	self.icon:SetSize(self.data["height"]-2, self.data["height"]-2)
	self.icon:SetMouseVisible(false)
	
	self.timerbar = Turbine.UI.Control()
	self.timerbar:SetParent(self.background)
	self.timerbar:SetSize(self.barsize, self.data["height"])
	self.timerbar:SetLeft(self.data["height"]-2)
	self.timerbar:SetBackColor(Turbine.UI.Color.Black)
	self.timerbar:SetOpacity(0)
	self.timerbar:SetMouseVisible(false)
	
	self.nameLabel = Turbine.UI.Label()
	self.nameLabel:SetParent(self.background)
	self.nameLabel:SetSize(((self.data["width"]-self.data["height"])-self.data["width"]*0.01)-40, self.data["height"]-2)
	self.nameLabel:SetLeft(self.data["height"]+self.data["width"]*0.01)
	self.nameLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
	self.nameLabel:SetFont(findfont(self.data["font"]))
	self.nameLabel:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.nameLabel:SetText(sender:GetName())
	self.nameLabel:SetMouseVisible(false)

	self.timeLabel = Turbine.UI.Label()
	self.timeLabel:SetParent(self.background)
	self.timeLabel:SetSize((self.data["width"]-self.data["width"]*0.01)-2, self.data["height"]-2)
	self.timeLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight)
	self.timeLabel:SetFont(findfont(self.data["font"]))
	self.timeLabel:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.timeLabel:SetMouseVisible(false)

	self:SetWantsUpdates(true)

end

function Bar:Ending()

	if self.followEndPoint ~= 0 then
			
		self.endPoint = self.followEndPoint
		self.followEndPoint = 0
	
	else
	
		self:SetWantsUpdates(false)
		self:Remove()
		self:GetParent()self:GetParent():RemoveItem(self)
		
	end

end

function Bar:NormalUpdate(timeLeft)

	local percent = timeLeft/self.duration
	
	self.timerbar:SetWidth(percent*self.barsize)
	self.timerbar:SetOpacity(percent)		
	self.timeLabel:SetText(SecondsToClock(math.floor(timeLeft)))
	
	if self.inThreshold == true then
		self.background:SetBackColor(Turbine.UI.Color(0.3,0.3,0.3))
	end

end

function Bar:ThresholdUpdate(timeLeft)

	local percent = timeLeft/self.duration
	
	self.timerbar:SetWidth(percent*self.barsize)
	self.timerbar:SetOpacity(percent)		
	self.timeLabel:SetText(SecondsToClock(math.floor(timeLeft)))
	
	if self.inThreshold == false then
		self.background:SetBackColor(Turbine.UI.Color.Red)
	end

end

function Bar:Update()

	local timeLeft = self.endPoint-Turbine.Engine.GetGameTime()
	
	
	if timeLeft < 0 then 
	
		self:Ending()
	
	elseif timeLeft < self.threshold then
	
		self:ThresholdUpdate(timeLeft)
	
	else
	
		self:NormalUpdate(timeLeft)
	
	end

end

function Bar:Remove()

	self:SetVisible(false)
	self.background:SetVisible(false)

end