

---------------------------------------------------------------------
--== LoadSelection ===--
---------------------------------------------------------------------


LoadSelection = class(Turbine.UI.Control)

function LoadSelection:Constructor(width, height)
	Turbine.UI.Control.Constructor( self )

	self.controlList = {}
	self.selection = nil
	self.width = width
	
	self.searchText = ""
	
	self:SetSize(width, height)
	self:SetBackColor(Turbine.UI.Color(0.3,0.3,0.3))
	
	self.ListBox = Turbine.UI.ListBox()
	self.ListBox:SetParent(self)	
	self.ListBox:SetPosition(1,26)
	self.ListBox:SetSize(self:GetWidth()-2,self:GetHeight()-50)
	self.ListBox:SetBackColor(Turbine.UI.Color(0.1,0.1,0.1))
	self.Scroll = Turbine.UI.Lotro.ScrollBar()
	self.Scroll:SetOrientation(Turbine.UI.Orientation.Vertical)
	self.Scroll:SetParent(self.ListBox)
	self.Scroll:SetPosition(self.ListBox:GetWidth()-12,0)
	self.Scroll:SetWidth(12)
	self.Scroll:SetZOrder(100)
	self.Scroll:SetHeight(self.ListBox:GetHeight())
	self.ListBox:SetVerticalScrollBar(self.Scroll)
	
	self.search = Turbine.UI.Lotro.TextBox()
	self.search:SetSize(width-2, 25)
	self.search:SetPosition(1,1)
	self.search:SetParent(self)
	self.search:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
	self.search:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.search:SetForeColor(Turbine.UI.Color(0.7,0.7,0.7))
	self.search:SetText("search ...")
	self.search.FocusGained = function(sender, args)
		self.search:SetForeColor(Turbine.UI.Color.White)
		if self.searchText == "" then
			self.search:SetText("")
		end
		
	end
	self.search.FocusLost = function(sender, args)
		self.search:SetForeColor(Turbine.UI.Color(0.7,0.7,0.7))
		if self.searchText == "" then
			self.search:SetText("search ...")
		end
	end
	self.search.TextChanged = function(sender, args)
		
		self.searchText = string.lower(self.search:GetText())
		self:FilterWindows()

	end

	self.loadedLabel = Turbine.UI.Label()
	self.loadedLabel:SetSize(width, 20)
	self.loadedLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.loadedLabel:SetFont(Turbine.UI.Lotro.Font.TrajanPro13)
	self.loadedLabel:SetText("- loaded -")
	
	self.loadedListBox = Turbine.UI.ListBox()
	self.loadedListBox:SetSize(width, 0)
	
	self.notloadedLabel = Turbine.UI.Label()
	self.notloadedLabel:SetSize(width, 20)
	self.notloadedLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.notloadedLabel:SetFont(Turbine.UI.Lotro.Font.TrajanPro13)
	self.notloadedLabel:SetText("- not loaded -")
	
	self.notloadedListBox = Turbine.UI.ListBox()
	self.notloadedListBox:SetSize(width, 0)
	
--	self.ListBox:AddItem(self.search)
	self.ListBox:AddItem(self.loadedLabel)
	self.ListBox:AddItem(self.loadedListBox)
	self.ListBox:AddItem(self.notloadedLabel)
	self.ListBox:AddItem(self.notloadedListBox)
	
	self.new = Turbine.UI.Lotro.Button()
	self.new:SetParent(self)
	self.new:SetSize(50,25)
	self.new:SetPosition(0,height-22)
	self.new:SetText("New")	
	self.new.MouseClick = function(sender,args)
		local index = AddNewWindow()
		self:FillControlList()
		self.selection = self.controlList[index]
		self.controlList[index]:Selected()
		self.delete:SetEnabled(true)
	end

	self.delete = Turbine.UI.Lotro.Button()
	self.delete:SetParent(self)
	self.delete:SetSize(60,25)
	self.delete:SetPosition(width-61,height-22)
	self.delete:SetText("Delete")
	self.delete:SetEnabled(false)	
	self.delete.MouseClick = function(sender,args)
		if self.selection ~= nil then
			RemoveWindow(self.selection.book["id"])
			self:FillControlList()
			self.delete:SetEnabled(false)
			self:GetParent():Deselect()
			CreateWindows()
		end
	end
	
	self:FillControlList()
		
	self:SetVisible(true)
	
end

function LoadSelection:ActivWindowNameChanged(name)
	if self.selection ~= nil then
		self.selection.label:SetText(name)
	end
end

function LoadSelection:FilterWindows()

	self.loadedListBox:ClearItems()
	self.notloadedListBox:ClearItems()
	
	for i, control in ipairs(self.controlList) do
		if string.find(string.lower(control.book["name"]), self.searchText) ~= nil then
			if control.settings["load"] then
				self.loadedListBox:AddItem(self.controlList[i])
			else
				self.notloadedListBox:AddItem(self.controlList[i])
			end
		end
	end
	self.loadedListBox:SetHeight(30*self.loadedListBox:GetItemCount())
	self.notloadedListBox:SetHeight(30*self.notloadedListBox:GetItemCount())


end

function LoadSelection:CheckedChanged()

	self.loadedListBox:ClearItems()
	self.notloadedListBox:ClearItems()
	
	for i, control in ipairs(self.controlList) do
		if control.settings["load"] then
			self.loadedListBox:AddItem(self.controlList[i])
		else
			self.notloadedListBox:AddItem(self.controlList[i])
		end		
	end
	
	self.loadedListBox:SetHeight(30*self.loadedListBox:GetItemCount())
	self.notloadedListBox:SetHeight(30*self.notloadedListBox:GetItemCount())

end 

function LoadSelection:SelectionChanged(control)

	self.selection = control

	for i, control in ipairs(self.controlList) do
		control.background:SetBackColor(Turbine.UI.Color(0.1,0.1,0.1))
	end
	
	self.delete:SetEnabled(true)

end

function LoadSelection:FillControlList()

	self.searchText = ""
	self.search:SetText("search ...")
	self.selection = nil
	self.loadedListBox:ClearItems()
	self.notloadedListBox:ClearItems()
	self.controlList = {}
	
	for i,book in ipairs(EffectsLibrary) do
	
		for j,settings in ipairs(CharacterSettings["window"]) do

			if book["id"] == settings["bookID"] then
				self.controlList[i] =  BookControl(book, settings ,self.width-2)
				
				if settings["load"] then
					self.loadedListBox:AddItem(self.controlList[i])
				else
					self.notloadedListBox:AddItem(self.controlList[i])
				end
			end
	
		end

	end
	
	self.loadedListBox:SetHeight(30*self.loadedListBox:GetItemCount())
	self.notloadedListBox:SetHeight(30*self.notloadedListBox:GetItemCount())

end

function LoadSelection:Resize(height)

	self:SetHeight(height)
	self.ListBox:SetHeight(height-50)
	self.Scroll:SetHeight(height-50)
	self.new:SetTop(height-22)
	self.delete:SetTop(height-22)

end

---------------------------------------------------------------------
--== BookControl ===--
---------------------------------------------------------------------

BookControl = class(Turbine.UI.Control)

function BookControl:Constructor(book, settings, width)
	Turbine.UI.Control.Constructor( self )
	
	self.book = book
	self.settings = settings

	self:SetSize(width, 30)
	
	self.background = Turbine.UI.Control()
	self.background:SetParent(self)
	self.background:SetMouseVisible(false)
	self.background:SetSize(width, 30)
	self.background:SetPosition(0,0)
	self.background:SetBackColor(Turbine.UI.Color(0.1,0.1,0.1))
	self.background:SetZOrder(2)
	
	self.loadCheck =  Turbine.UI.Lotro.CheckBox()
	self.loadCheck:SetParent(self)
	self.loadCheck:SetMouseVisible(false)
	self.loadCheck:SetSize(26, 26)
	self.loadCheck:SetPosition(5,2)
	self.loadCheck:SetFont(Turbine.UI.Lotro.Font.Verdana22)
	self.loadCheck:SetText("")
	self.loadCheck:SetChecked(settings["load"])
	self.loadCheck:SetZOrder(3)
	
	self.label =  Turbine.UI.Label()
	self.label:SetParent(self)
	self.label:SetMouseVisible(false)
	self.label:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
	self.label:SetSize(width-35, 26)
	self.label:SetPosition(33,2)
	self.label:SetFont(Turbine.UI.Lotro.Font.Verdana22)
	self.label:SetText(book["name"])
	self.label:SetZOrder(4)
	
	self.loadCheck.CheckedChanged = function(sender, args)
		self.settings["load"] = self.loadCheck:IsChecked()
		self:GetParent():GetParent():GetParent():CheckedChanged()
		saveLibrary()
		CreateWindows()
	end
	
	self.MouseEnter = function(sender, args)
		if self:GetParent():GetParent().seletion ~= self then
			self.background:SetBackColor(Turbine.UI.Color(0.3,0.3,0.3))
		end
	end
	
	self.MouseLeave = function(sender, args)
		if self:GetParent():GetParent().seletion ~= self then
			self.background:SetBackColor(Turbine.UI.Color(0.1,0.1,0.1))
		end
	end
	
	self.MouseClick = function(sender, args)
		
		self:GetParent():GetParent():GetParent():SelectionChanged(self)
		self:Selected()		
	end

end

function BookControl:Selected()
	self.background:SetBackColor(Turbine.UI.Color.Orange)
	self:GetParent():GetParent().seletion = self
	self:GetParent():GetParent():GetParent():GetParent():FillSelected(self.book, self.settings)
end


