

---------------------------------------------------------------------
--== List ===--
---------------------------------------------------------------------


EffectList = class(Turbine.UI.Control)

function EffectList:Constructor(width, height, effects, aktivList, backgroundColor, realEffect)
	Turbine.UI.Control.Constructor( self )
	
	self.selection = nil
	
	if backgroundColor ~= nil then
		self.color = backgroundColor
	else
		self.color = Turbine.UI.Color.Black
	end
	
	self.controls = {}
	self.width = width
	self.effects = effects	
	self.aktivList = aktivList
	self.searchText = ""
		
	self.realEffect = realEffect

	
	self:SetSize(width, height)
	self:SetBackColor(Turbine.UI.Color(0.3,0.3,0.3))
	
	self.list = Turbine.UI.ListBox()
	self.list:SetParent(self)
	self.list:SetPosition(1,26)
	self.list:SetSize(width-2, height-50)
	self.list:SetBackColor(self.color)
	
	self.Scroll = Turbine.UI.Lotro.ScrollBar()
	self.Scroll:SetOrientation(Turbine.UI.Orientation.Vertical)
	self.Scroll:SetParent(self.list)
	self.Scroll:SetPosition(self.list:GetWidth()-12,0)
	self.Scroll:SetWidth(12)
	self.Scroll:SetZOrder(100)
	self.Scroll:SetHeight(self.list:GetHeight())
	self.list:SetVerticalScrollBar(self.Scroll)
	
	self.search = Turbine.UI.Lotro.TextBox()
	self.search:SetSize(width-2, 25)
	self.search:SetPosition(1,1)
	self.search:SetParent(self)
	self.search:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
	self.search:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.search:SetForeColor(Turbine.UI.Color(0.7,0.7,0.7))
	self.search:SetText("Search ...")
	self.search.FocusGained = function(sender, args)
		self.search:SetForeColor(Turbine.UI.Color.White)
		if self.searchText == "" then
			self.search:SetText("")
		end
		
	end
	self.search.FocusLost = function(sender, args)
		self.search:SetForeColor(Turbine.UI.Color(0.7,0.7,0.7))
		if self.searchText == "" then
			self.search:SetText("Search ...")
		end
	end
	self.search.TextChanged = function(sender, args)
		
		self.searchText = string.lower(self.search:GetText())
		self:FilterWindows()

	end
	
	self.buffLabel = Turbine.UI.Label()
	self.buffLabel:SetSize(width-2, 20)
	self.buffLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.buffLabel:SetFont(Turbine.UI.Lotro.Font.TrajanPro13)
	self.buffLabel:SetText("- buffs -")
	
	self.buffs = Turbine.UI.ListBox()
	self.buffs:SetSize(width-2, 0)
	
	self.debuffLabel = Turbine.UI.Label()
	self.debuffLabel:SetSize(width-2, 20)
	self.debuffLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.debuffLabel:SetFont(Turbine.UI.Lotro.Font.TrajanPro13)
	self.debuffLabel:SetText("- debuffs -")
	
	self.debuffs = Turbine.UI.ListBox()
	self.debuffs:SetSize(width-2, 0)
	
	--self.list:AddItem(self.search)
	self.list:AddItem(self.debuffLabel)
	self.list:AddItem(self.debuffs)
	self.list:AddItem(self.buffLabel)
	self.list:AddItem(self.buffs)
	
	self.delete = Turbine.UI.Lotro.Button()
	self.delete:SetParent(self)
	self.delete:SetSize(60,25)
	self.delete:SetPosition(width-61,height-22)
	self.delete:SetText("Delete")
	self.delete:SetEnabled(false)	
	self.delete.MouseClick = function(sender,args)
		if self.selection ~= nil then
			
			if self.realEffect == false then
				
				local page = self.selection.effect
				local index = nil
				
				for i,x in ipairs(self.effects) do
					if page == x then
						index = i
						break
					end
				end
			
				if index ~= nil then
					for j=index, table.getn(self.effects)-1, 1 do
						self.effects[j] = self.effects[j+1]
					end
					self.effects[table.getn(self.effects)] = nil
					
					saveLibrary()

					self:UpdateLists(self.effects, self.aktivList)
				end
				
			end
			
		end
	end
	
	if effects ~= nil then
	
		if self.realEffect then
		
			for i,effect in ipairs(effects) do
				self.controls[i] = EffectListItem(width, effect,self:Check(effect),self.color, aktivList, self.realEffect)
				if effect:IsDebuff() then
					self.debuffs:AddItem(self.controls[i])
				else
					self.buffs:AddItem(self.controls[i])
				end
			end
		
		else
		
		for i,effect in ipairs(effects) do
				self.controls[i] = EffectListItem(width, effect,self:Check(effect),self.color, aktivList, self.realEffect)
				if effect["isdebuff"] then
					self.debuffs:AddItem(self.controls[i])
				else
					self.buffs:AddItem(self.controls[i])
				end
			end
	
		
			
		end
		
	end
	self.debuffs:SetHeight(36*self.debuffs:GetItemCount())
	self.buffs:SetHeight(36*self.buffs:GetItemCount())

end

function EffectList:FilterWindows()

	self.debuffs:ClearItems()
	self.buffs:ClearItems()
	
	for i, control in ipairs(self.controls) do
		if string.find(control.effect["name"], self.searchText) ~= nil then
			if control.effect["isdebuff"] then
				self.debuffs:AddItem(self.controls[i])
			else
				self.buffs:AddItem(self.controls[i])
			end
		end
	end
	
	self.debuffs:SetHeight(36*self.debuffs:GetItemCount())
	self.buffs:SetHeight(36*self.buffs:GetItemCount())

end

function EffectList:SelectionChanged(control)
	self.selection = control

	for i=1, self.debuffs:GetItemCount(), 1 do
		self.debuffs:GetItem(i).background:SetBackColor(self.color)
	end
	for j=1, self.buffs:GetItemCount(), 1 do
		self.buffs:GetItem(j).background:SetBackColor(self.color)
	end
	
	self.delete:SetEnabled(true)
	
end

function EffectList:UpdateLists(effects, aktivList)

	self.delete:SetEnabled(false)

	self.controls = {}
	self.effects = effects	
	self.aktivList = aktivList

	self.debuffs:ClearItems()
	self.buffs:ClearItems()
	
	if effects ~= nil then
	
		if self.realEffect then 
		
			for i,effect in ipairs(effects) do
				self.controls[i] = EffectListItem(self.width, effect,self:Check(effect),self.color, aktivList, self.realEffect)
				if effect:IsDebuff() then
					self.debuffs:AddItem(self.controls[i])
				else
					self.buffs:AddItem(self.controls[i])
				end
			end
		
		else
	
			for i,effect in ipairs(effects) do
				self.controls[i] = EffectListItem(self.width, effect,self:Check(effect),self.color, aktivList, self.realEffect)
				if effect["isdebuff"] then
					self.debuffs:AddItem(self.controls[i])
				else
					self.buffs:AddItem(self.controls[i])
				end
			end
		
		end
		
	end
	
	if self.searchText ~= "" then
		self:FilterWindows()
	end
	
	self.debuffs:SetHeight(36*self.debuffs:GetItemCount())
	self.buffs:SetHeight(36*self.buffs:GetItemCount())
end

function EffectList:Resize(height)

	self:SetHeight(height)
	self.list:SetHeight(height-50)
	self.Scroll:SetHeight(height-50)
	self.delete:SetTop(height-22)

end

function EffectList:Check(effect)

	local name
	local icon

	if self.realEffect then
	
		name = string.lower(effect:GetName())
		icon = effect:GetIcon()
	
	else

		name = effect["name"]
		icon = effect["icon"]
		
	end	
	
	if self.aktivList ~= nil then
		for i,e in ipairs(self.aktivList) do
			if e["name"] == name then
				if e["icon"] == icon then
					return true
				end
			end
		end
	end

	
	return false
	
end

---------------------------------------------------------------------
--== Item ===--
---------------------------------------------------------------------

EffectListItem = class(Turbine.UI.Control)

function EffectListItem:Constructor(width, effect, checked, color, aktivList, realEffect)
	Turbine.UI.Control.Constructor( self )
	
	if color ~= nil then
		self.color = color
	else
		self.color = Turbine.UI.Color.Black
	end
	
	self.realEffect = realEffect
	self.effect = effect
	
	self:SetSize(width, 36)
	
	self.background = Turbine.UI.Control()
	self.background:SetParent(self)
	self.background:SetMouseVisible(false)
	self.background:SetSize(width, 36)
	self.background:SetPosition(0,0)
	self.background:SetBackColor(self.color)
	self.background:SetZOrder(2)

	self.label =  Turbine.UI.Label()
	self.label:SetParent(self)
	self.label:SetMouseVisible(false)
	self.label:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
	self.label:SetSize(width-72, 36)
	self.label:SetPosition(38,2)
	self.label:SetFont(Turbine.UI.Lotro.Font.Verdana12)

	self.label:SetZOrder(4)
	
	if realEffect then
	
		self.icon = Turbine.UI.Lotro.EffectDisplay()
		self.icon:SetParent(self)
		self.icon:SetPosition(2,2)
		self.icon:SetZOrder(3)
		self.icon:SetSize(32, 32)
	
		self.icon:SetEffect(self.effect)
		self.label:SetText(effect:GetName())
	
	else
	
		self.icon = Turbine.UI.Control()
		self.icon:SetParent(self)
		self.icon:SetMouseVisible(false)
		self.icon:SetPosition(2,2)
		self.icon:SetZOrder(3)
		self.icon:SetSize(32, 32)
	
		if effect["icon"] ~= nil then
			self.icon:SetBackground(effect["icon"])
		else
			self.icon:SetBackColor(Turbine.UI.Color(0.2,0.2,0.2))
		end
		self.label:SetText(effect["name"])
	
	end
	

	
	self.check =  Turbine.UI.Lotro.CheckBox()
	self.check:SetParent(self)
	self.check:SetMouseVisible(false)
	self.check:SetSize(32, 32)
	self.check:SetPosition(width-35,2)
	self.check:SetChecked(checked)
	self.check:SetZOrder(5)
	self.check:SetText("")
	if aktivList == nil then
		self.check:SetEnabled(false)
	end
	
	self.check.CheckedChanged = function(sender, args)
		
		if self.realEffect then
			local b = {}
			b["name"] = string.lower(self.effect:GetName())	
			b["icon"] = self.effect:GetIcon()
			b["isdebuff"] = self.effect:IsDebuff()
			self:GetParent():GetParent():GetParent():GetParent():EffectStatusChanged(b, self.check:IsChecked())
		else
			self:GetParent():GetParent():GetParent():GetParent():EffectStatusChanged(self.effect, self.check:IsChecked())
		end

		self.MouseLeave = function(sender, args)end
	end
	
	self.MouseEnter = function(sender, args)
		if self:GetParent():GetParent():GetParent().selection ~= self then
			self.background:SetBackColor(Turbine.UI.Color(0.3,0.3,0.3))
		end
	end
	
	self.MouseLeave = function(sender, args)
		if self:GetParent():GetParent():GetParent().selection ~= self then
			self.background:SetBackColor(self.color)
		end
	end
	
	self.MouseClick = function(sender, args)
		
		self:GetParent():GetParent():GetParent():SelectionChanged(self)
		self:Selected()		
	end

end

function EffectListItem:Selected()
	self.background:SetBackColor(Turbine.UI.Color.Orange)
	self:GetParent():GetParent():GetParent().seletion = self
end
