

---------------------------------------------------------------------
--== Panel ===--
---------------------------------------------------------------------


OptionsPanel = class(Turbine.UI.Control)

function OptionsPanel:Constructor(width, height)
	Turbine.UI.Control.Constructor( self )
	
	self.selectedBook = nil
	self.selectedSettings = nil

	self:SetSize(width-100, height)
	self:SetBackColor(Turbine.UI.Color(0.3,0.3,0.3))
	
	self.list = Turbine.UI.ListBox()
	self.list:SetParent(self)	
	self.list:SetPosition(1,1)
	self.list:SetSize(width-102,self:GetHeight()-25)
	self.list:SetBackColor(Turbine.UI.Color(0.1,0.1,0.1))
	
	self.Scroll = Turbine.UI.Lotro.ScrollBar()
	self.Scroll:SetOrientation(Turbine.UI.Orientation.Vertical)
	self.Scroll:SetParent(self)
	self.Scroll:SetPosition(width-12,0)
	self.Scroll:SetWidth(12)
	self.Scroll:SetZOrder(100)
	self.Scroll:SetHeight(height)
	self.list:SetVerticalScrollBar(self.Scroll)

	self.namepanel = NamePanel()
	self.valuepanel = ValuePanel()

	self.list:AddItem(self.namepanel)
	self.list:AddItem(self.valuepanel)
	
	self.accept = Turbine.UI.Lotro.Button()
	self.accept:SetParent(self)
	self.accept:SetSize(60,25)
	self.accept:SetPosition(width-31,height-22)
	self.accept:SetText("Accept")	
	self.accept.MouseClick = function(sender,args)
		self:SaveChanges()
	end
	if book == nil and settings == nil then
		self.accept:SetEnabled(false)
	end

	self:SetVisible(true)
	
end


function OptionsPanel:FillSelected(book, settings)

	self.selectedBook  = book
	self.selectedSettings = settings
	
	

	if book ~= nil and settings ~= nil then
		self.accept:SetEnabled(true)
		self.namepanel.textbox:SetEnabled(true)
		self.valuepanel.width:SetEnabled(true)
		self.valuepanel.height:SetEnabled(true)
		self.valuepanel.spacing:SetEnabled(true)
		self.valuepanel.selectFont:SetEnabled(true)
		self.valuepanel.threshold:SetEnabled(true)

		self.namepanel.textbox:SetText(book["name"])
		self.valuepanel.width:SetText(settings["width"])
		self.valuepanel.height:SetText(settings["height"])
		self.valuepanel.spacing:SetText(settings["spacing"])
		self.valuepanel.threshold:SetText(settings["threshold"])
		self.valuepanel.selectFont:SetSelection(settings["font"])
		
	else
		self.accept:SetEnabled(false)
		self.namepanel.textbox:SetEnabled(false)
		self.valuepanel.width:SetEnabled(false)
		self.valuepanel.height:SetEnabled(false)
		self.valuepanel.spacing:SetEnabled(false)
		self.valuepanel.selectFont:SetEnabled(false)
		self.valuepanel.threshold:SetEnabled(false)
	
		self.namepanel.textbox:SetText("")
		self.valuepanel.width:SetText("")
		self.valuepanel.height:SetText("")
		self.valuepanel.spacing:SetText("")
		self.valuepanel.selectFont:SetSelection("")
	
	end

end

function OptionsPanel:Resize(width, height)

	self:SetSize(width-100, height)
	self.list:SetSize(width-102, height-25)
	self.Scroll:SetPosition(width-12,0)
	self.Scroll:SetHeight(height)
	self.accept:SetTop(height-22)

end

function OptionsPanel:SaveChanges()

	if self.selectedBook ~= nil and self.selectedSettings ~= nil then
	
		self.selectedBook["name"] = self.namepanel.textbox:GetText()
		self.selectedSettings["width"] = self.valuepanel.width:GetText()
		self.selectedSettings["height"] = self.valuepanel.height:GetText()
		self.selectedSettings["spacing"] = self.valuepanel.spacing:GetText()
		self.selectedSettings["threshold"] = self.valuepanel.threshold:GetText()
		self.selectedSettings["font"] = self.valuepanel.selectFont:GetSelection()
		
		self:GetParent():ActivWindowNameChanged(self.selectedBook["name"])
		saveLibrary()
		saveSettings()
		CreateWindows()
	
	end

end

---------------------------------------------------------------------
--== Name ===--
---------------------------------------------------------------------

NamePanel = class(Turbine.UI.Control)

function NamePanel:Constructor()
	Turbine.UI.Control.Constructor( self )

	self:SetSize(400, 55)

	self.textbox = Turbine.UI.Lotro.TextBox()
	self.textbox:SetParent(self)
	self.textbox:SetSize(200,25)
	self.textbox:SetPosition(10,15)
	self.textbox:SetFont(Turbine.UI.Lotro.Font.Verdana16)
	self.textbox:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
	self.textbox:SetEnabled(false)
	
	self.label = Turbine.UI.Label()
	self.label:SetParent(self)
	self.label:SetSize(100, 25)
	self.label:SetPosition(220,20)
	self.label:SetTextAlignment(Turbine.UI.ContentAlignment.LeftCenter)
	self.label:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.label:SetText("//name")

end

---------------------------------------------------------------------
--== Values ===--
---------------------------------------------------------------------


ValuePanel = class(Turbine.UI.Control)

function ValuePanel:Constructor()
	Turbine.UI.Control.Constructor( self )

	self:SetSize(400, 135)

	self.width = Turbine.UI.Lotro.TextBox()
	self.width:SetParent(self)
	self.width:SetSize(50,25)
	self.width:SetPosition(10,15)
	self.width:SetFont(Turbine.UI.Lotro.Font.Verdana16)
	self.width:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
	self.width:SetEnabled(false)
	
	self.wlabel = Turbine.UI.Label()
	self.wlabel:SetParent(self)
	self.wlabel:SetSize(100, 25)
	self.wlabel:SetPosition(70,20)
	self.wlabel:SetTextAlignment(Turbine.UI.ContentAlignment.LeftCenter)
	self.wlabel:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.wlabel:SetText("//width")
	
	self.height = Turbine.UI.Lotro.TextBox()
	self.height:SetParent(self)
	self.height:SetSize(50,25)
	self.height:SetPosition(140,15)
	self.height:SetFont(Turbine.UI.Lotro.Font.Verdana16)
	self.height:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
	self.height:SetEnabled(false)
	
	self.hlabel = Turbine.UI.Label()
	self.hlabel:SetParent(self)
	self.hlabel:SetSize(100, 25)
	self.hlabel:SetPosition(200,20)
	self.hlabel:SetTextAlignment(Turbine.UI.ContentAlignment.LeftCenter)
	self.hlabel:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.hlabel:SetText("//height")
	
	self.spacing = Turbine.UI.Lotro.TextBox()
	self.spacing:SetParent(self)
	self.spacing:SetSize(50,25)
	self.spacing:SetPosition(10,55)
	self.spacing:SetFont(Turbine.UI.Lotro.Font.Verdana16)
	self.spacing:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
	self.spacing:SetEnabled(false)
	
	self.slabel = Turbine.UI.Label()
	self.slabel:SetParent(self)
	self.slabel:SetSize(100, 25)
	self.slabel:SetPosition(70,60)
	self.slabel:SetTextAlignment(Turbine.UI.ContentAlignment.LeftCenter)
	self.slabel:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.slabel:SetText("//spacing")
	
	self.threshold = Turbine.UI.Lotro.TextBox()
	self.threshold:SetParent(self)
	self.threshold:SetSize(50,25)
	self.threshold:SetPosition(140,55)
	self.threshold:SetFont(Turbine.UI.Lotro.Font.Verdana16)
	self.threshold:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft)
	self.threshold:SetEnabled(false)
	
	self.tlabel = Turbine.UI.Label()
	self.tlabel:SetParent(self)
	self.tlabel:SetSize(100, 25)
	self.tlabel:SetPosition(200,60)
	self.tlabel:SetTextAlignment(Turbine.UI.ContentAlignment.LeftCenter)
	self.tlabel:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.tlabel:SetText("//threshold")
	
	self.selectFont = LabelledComboBox(nil, nil, 160)
	self.selectFont:SetParent(self)
	self.selectFont:SetPosition(10,95)
	self.selectFont:AddItem("Arial 12", 1);
	self.selectFont:AddItem("TrajanPro 13", 2);
	self.selectFont:AddItem("TrajanPro 14", 3);
	self.selectFont:AddItem("TrajanPro 15", 4);
	self.selectFont:AddItem("TrajanPro 16", 5);
	self.selectFont:AddItem("TrajanPro 18", 6);
	self.selectFont:AddItem("TrajanPro 19", 7);
	self.selectFont:AddItem("TrajanPro 20", 8);
	self.selectFont:AddItem("TrajanPro 21", 9);
	self.selectFont:AddItem("TrajanPro 23", 10);
	self.selectFont:AddItem("TrajanPro 24", 11);
	self.selectFont:AddItem("TrajanPro 25", 12);
	self.selectFont:AddItem("TrajanPro 26", 13);
	self.selectFont:AddItem("TrajanPro 28", 14);
	self.selectFont:AddItem("TrajanProBold 16", 15);
	self.selectFont:AddItem("TrajanProBold 22", 16);
	self.selectFont:AddItem("TrajanProBold 24", 17);
	self.selectFont:AddItem("TrajanProBold 25", 18);
	self.selectFont:AddItem("TrajanProBold 30", 19);
	self.selectFont:AddItem("TrajanProBold 36", 20);
	self.selectFont:AddItem("Verdana 10", 21);
	self.selectFont:AddItem("Verdana 12", 22);
	self.selectFont:AddItem("Verdana 14", 23);
	self.selectFont:AddItem("Verdana 16", 24);
	self.selectFont:AddItem("Verdana 18", 25);
	self.selectFont:AddItem("Verdana 20", 26);
	self.selectFont:AddItem("Verdana 22", 27);
	self.selectFont:AddItem("Verdana 23", 28);
	self.selectFont:SetEnabled(false)

	self.flabel = Turbine.UI.Label()
	self.flabel:SetParent(self)
	self.flabel:SetSize(100, 25)
	self.flabel:SetPosition(180,100)
	self.flabel:SetTextAlignment(Turbine.UI.ContentAlignment.LeftCenter)
	self.flabel:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.flabel:SetText("//font")

end

















