
Window = class( Turbine.UI.Window )

function Window:Constructor(data)
	Turbine.UI.Window.Constructor( self )
	
	self.data = data
	
	self:SetVisible(true)
	self:SetMouseVisible(false)
	self:SetSize(self.data["width"],self.data["height"])
	self:SetPosition(self.data["left"],self.data["top"])

	self.listbox = Turbine.UI.ListBox()
	self.listbox:SetParent(self)
	self.listbox:SetSize(self.data["width"],self.data["height"])
	self.listbox:SetVisible(true)
	self.listbox:SetMouseVisible(false)

	self.moveWindow = Turbine.UI.Window()
	self.moveWindow:SetParent(self)
	self.moveWindow:SetSize(self.data["width"],self.data["height"])
	self.moveWindow:SetMouseVisible(moving)
	self.moveWindow:SetVisible(moving)
	
	self.moveLabel = Turbine.UI.Label()
	self.moveLabel:SetParent(self.moveWindow)
	self.moveLabel:SetPosition(1,1)
	self.moveLabel:SetSize(self.data["width"]-2,self.data["height"]-2)
	self.moveLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
	self.moveLabel:SetFont(Turbine.UI.Lotro.Font.Verdana12)
	self.moveLabel:SetFontStyle(Turbine.UI.FontStyle.Outline)
	self.moveLabel:SetVisible(true)
	self.moveLabel:SetMouseVisible(false)
	
	if self.data["load"] then
		self.moveWindow:SetBackColor(Turbine.UI.Color(0.3,0.3,0.3))
		self.moveLabel:SetBackColor(Turbine.UI.Color.Black)
		self.moveLabel:SetForeColor(Turbine.UI.Color.White)
	else
		self.moveWindow:SetBackColor(Turbine.UI.Color.Black)
		self.moveLabel:SetBackColor(Turbine.UI.Color(0.3,0.3,0.3))
		self.moveLabel:SetForeColor(Turbine.UI.Color(0.6,0.6,0.6))
	end
	
	
	local bookID = data["bookID"]
	
	for i,x in ipairs(EffectsLibrary) do
		if x["id"] == bookID then
			self.moveLabel:SetText(x["name"])
			break
		end
	end
	
	self.moveWindow.MouseDown = function( sender, args )
		if args.Button == Turbine.UI.MouseButton.Left then
			self.dragging = true	
			self.dragStartX = args.X
			self.dragStartY = args.Y
		end
	
	end
	
	self.moveWindow.MouseMove = function( sender, args )
		if self.dragging then
			local x,y = self:GetPosition()	
			x = x + ( args.X - self.dragStartX )
			y = y + ( args.Y - self.dragStartY )	
			self:SetPosition( x, y )	
		end
	end
	
	self.moveWindow.MouseUp = function( sender, args )
		if args.Button == Turbine.UI.MouseButton.Left then
			self.dragging = false
			self.data["left"],self.data["top"] = self:GetPosition()
				
			saveSettings()
		end
	end

end

function Window:Move(bool)

	self.moveWindow:SetVisible(bool)
	self.moveWindow:SetMouseVisible(bool)
end

function Window:RemoveItem(item)		
	self.listbox:RemoveItem(item)		
end

function Window:Resize()

	local height = self.listbox:GetItemCount()*(self.data["height"]+self.data["spacing"])

	self:SetHeight(height)
	self.listbox:SetHeight(height)

end

function Window:EffectAdded(effect, sender)

	if self.data["load"] then
	
		local itemCount = self.listbox:GetItemCount()
		
		if itemCount > 0 then
	
			local name = string.lower(effect:GetName())
			
			for i=1, itemCount, 1 do
			
				local item = self.listbox:GetItem(i)
			
				if name == item.name then
				
					if sender == item.sender then
						
						if effect:GetDuration() < 999 then
							local endPoint = effect:GetDuration()+effect:GetStartTime()
											
							if item.endPoint < endPoint then
								if item.followEndPoint < endPoint then
									item.followEndPoint = endPoint
								end
							end
						end
						
						return
					
					end
				
				end
			
			end

		end

		self.listbox:AddItem(Bar(effect, self.data, string.lower(effect:GetName()), sender))
	    self.listbox:Sort(function(elem1,elem2) if elem1.endPoint<elem2.endPoint then return true end end)
	
		self:Resize()

	end

end


function Window:Remove()

	self:SetVisible(false)

end